# Generated by Django 4.0.6 on 2022-12-15 05:48

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("core", "0034_term_disabled"),
    ]

    operations = [
        migrations.AlterField(
            model_name="email",
            name="type",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "emailtype"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="type_%(app_label)s_%(class)s_list",
                to="core.term",
                verbose_name="Type",
            ),
        ),
        migrations.AlterField(
            model_name="fax",
            name="type",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "phonetype"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="core.term",
                verbose_name="Type",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnaturalperson",
            name="form_of_address",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                limit_choices_to={"vocabulary__slug": "form_of_address"},
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="core.term",
                verbose_name="Form of address",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnaturalperson",
            name="gender",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                limit_choices_to={"vocabulary__slug": "gender"},
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="core.term",
                verbose_name="Gender",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnaturalperson",
            name="salutation",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                limit_choices_to={"vocabulary__slug": "salutation"},
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="core.term",
                verbose_name="Salutation",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnaturalperson",
            name="title",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                limit_choices_to={"vocabulary__slug": "title"},
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="core.term",
                verbose_name="Title",
            ),
        ),
        migrations.AlterField(
            model_name="naturalperson",
            name="form_of_address",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "form_of_address"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="core.term",
                verbose_name="Form of address",
            ),
        ),
        migrations.AlterField(
            model_name="naturalperson",
            name="gender",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "gender"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="gender_persons",
                to="core.term",
                verbose_name="Gender",
            ),
        ),
        migrations.AlterField(
            model_name="naturalperson",
            name="salutation",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "salutation"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="core.term",
                verbose_name="Salutation",
            ),
        ),
        migrations.AlterField(
            model_name="naturalperson",
            name="title",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "title"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="title_persons",
                to="core.term",
                verbose_name="Title",
            ),
        ),
        migrations.AlterField(
            model_name="phone",
            name="type",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "phonetype"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="core.term",
                verbose_name="Type",
            ),
        ),
        migrations.AlterField(
            model_name="postal",
            name="type",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "addresstype"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="type_%(app_label)s_%(class)s_list",
                to="core.term",
                verbose_name="Type",
            ),
        ),
        migrations.AlterField(
            model_name="web",
            name="type",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "urltype"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="type_%(app_label)s_%(class)s_list",
                to="core.term",
                verbose_name="Type",
            ),
        ),
    ]
