# Generated by Django 4.1.7 on 2023-04-08 09:41

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("basxconnect_invoicing", "0002_alter_invoice_note"),
    ]

    operations = [
        migrations.AddField(
            model_name="invoice",
            name="receipt_sent",
            field=models.DateField(blank=True, null=True, verbose_name="Receipt sent"),
        ),
    ]
