# Generated by Django 3.2.5 on 2021-10-29 13:55

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("contributions", "0002_alter_contribution_currency"),
    ]

    operations = [
        migrations.AlterField(
            model_name="contribution",
            name="_import",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="contributions",
                to="contributions.contributionimport",
            ),
        ),
    ]
