# Generated by Django 3.2.5 on 2021-09-28 08:12

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("core", "0013_auto_20210928_1445"),
    ]

    operations = [
        migrations.RenameField(
            model_name="term",
            old_name="category",
            new_name="vocabulary",
        ),
        migrations.AlterField(
            model_name="email",
            name="status",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "addressstatus"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="status_core_email_list",
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="email",
            name="type",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "emailtype"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="type_core_email_list",
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="fax",
            name="status",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "addressstatus"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="status_core_fax_list",
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="fax",
            name="type",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "phonetype"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="historicallegalperson",
            name="type",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                limit_choices_to={"vocabulary__slug": "legaltype"},
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnaturalperson",
            name="form_of_address",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                limit_choices_to={"vocabulary__slug": "form_of_address"},
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnaturalperson",
            name="gender",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                limit_choices_to={"vocabulary__slug": "gender"},
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnaturalperson",
            name="salutation",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                limit_choices_to={"vocabulary__slug": "salutation"},
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnaturalperson",
            name="title",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                limit_choices_to={"vocabulary__slug": "title"},
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnaturalperson",
            name="type",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                limit_choices_to={"vocabulary__slug": "naturaltype"},
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpersonassociation",
            name="type",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                limit_choices_to={"vocabulary__slug": "associationtype"},
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="legalperson",
            name="type",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "legaltype"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="naturalperson",
            name="form_of_address",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "form_of_address"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="naturalperson",
            name="gender",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "gender"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="gender_persons",
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="naturalperson",
            name="salutation",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "salutation"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="naturalperson",
            name="title",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "title"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="title_persons",
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="naturalperson",
            name="type",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "naturaltype"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="person",
            name="categories",
            field=models.ManyToManyField(
                blank=True,
                limit_choices_to={"vocabulary__slug": "category"},
                to="core.Term",
            ),
        ),
        migrations.AlterField(
            model_name="personassociation",
            name="type",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "associationtype"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="phone",
            name="status",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "addressstatus"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="status_core_phone_list",
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="phone",
            name="type",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "phonetype"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="postal",
            name="status",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "addressstatus"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="status_core_postal_list",
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="postal",
            name="type",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "addresstype"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="type_core_postal_list",
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="web",
            name="status",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "addressstatus"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="status_core_web_list",
                to="core.term",
            ),
        ),
        migrations.AlterField(
            model_name="web",
            name="type",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"vocabulary__slug": "urltype"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="type_core_web_list",
                to="core.term",
            ),
        ),
    ]
