# Generated by Django 3.2.4 on 2021-11-19 13:01

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("core", "0023_auto_20211030_0955"),
        ("mailer_integration", "0013_mailingpreferences_latest_sync"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="MailingPreferences",
            new_name="Subscription",
        ),
    ]
