# Generated by Django 4.1.7 on 2023-02-20 04:49

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("mailer_integration", "0023_auto_20220517_1700"),
    ]

    operations = [
        migrations.AddField(
            model_name="synchronizationperson",
            name="maybe_duplicate",
            field=models.BooleanField(
                default=False,
                help_text="Other person with same first and last name already exists",
                verbose_name="Possible duplicate",
            ),
        ),
    ]
