# Generated by Django 3.2.4 on 2021-11-03 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("mailer_integration", "0010_mailingpreferences_language"),
    ]

    operations = [
        migrations.CreateModel(
            name="SynchronizationResult",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("total_synchronized_persons", models.IntegerField(null=True)),
                ("sync_completed_datetime", models.DateTimeField(null=True)),
            ],
        ),
        migrations.CreateModel(
            name="NewPerson",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("email", models.CharField(max_length=100)),
                (
                    "sync_result",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="new_persons",
                        to="mailer_integration.synchronizationresult",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="InvalidPerson",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("email", models.CharField(max_length=100)),
                (
                    "sync_result",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="invalid_new_persons",
                        to="mailer_integration.synchronizationresult",
                    ),
                ),
            ],
        ),
    ]
