# Generated by Django 3.2.4 on 2021-08-23 16:38

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("mailer_integration", "0005_alter_mailingpreferences_email"),
    ]

    operations = [
        migrations.AlterField(
            model_name="mailingpreferences",
            name="status",
            field=models.CharField(
                choices=[
                    ("subscribed", "subscribed"),
                    ("unsubscribed", "unsubscribed"),
                    ("non-subscribed", "non-subscribed"),
                    ("cleaned", "cleaned"),
                ],
                max_length=50,
            ),
        ),
    ]
